==> jc-1.4.0.tar.gz: ppg/parse/ParserError.h <==
// public class ppg.parse.ParserError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class f330be4620416da0 ppg_parse_ParserError

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_ppg_parse_ParserError_H_
#define _JC_ppg_parse_ParserError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_ppg_lex_Token$object;

// Typedefs
typedef struct _jc_ppg_parse_ParserError$sub_refs	_jc_ppg_parse_ParserError$sub_refs;
typedef struct _jc_ppg_parse_ParserError$sub_nonrefs	_jc_ppg_parse_ParserError$sub_nonrefs;
typedef struct _jc_ppg_parse_ParserError$refs	_jc_ppg_parse_ParserError$refs;
typedef struct _jc_ppg_parse_ParserError$nonrefs	_jc_ppg_parse_ParserError$nonrefs;
typedef struct _jc_ppg_parse_ParserError$object	_jc_ppg_parse_ParserError$object;

typedef const struct _jc_ppg_parse_ParserError$vmethods	_jc_ppg_parse_ParserError$vmethods;
typedef const struct _jc_ppg_parse_ParserError$vtable	_jc_ppg_parse_ParserError$vtable;
typedef const struct _jc_ppg_parse_ParserError$vtype	_jc_ppg_parse_ParserError$vtype;

// Constructors
extern void _jc_ppg_parse_ParserError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_parse_ParserError$object *);
extern void _jc_ppg_parse_ParserError$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_parse_ParserError$object *, struct _jc_java_lang_String$object *);
extern void _jc_ppg_parse_ParserError$method$_init$693b4a8377b96746(_jc_env *, struct _jc_ppg_parse_ParserError$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_ppg_lex_Token$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_parse_ParserError$method$getErrorMessage$88bf10365b208229(_jc_env *, struct _jc_ppg_parse_ParserError$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_parse_ParserError$method_info$getErrorMessage$88bf10365b208229;

// Virtual methods structure
struct _jc_ppg_parse_ParserError$vmethods {
	struct _jc_java_lang_String$object	*(*getErrorMessage$88bf10365b208229)(_jc_env *, struct _jc_ppg_parse_ParserError$object *);
};

// Vtable
struct _jc_ppg_parse_ParserError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_ppg_parse_ParserError$vmethods	ppg_parse_ParserError;
};

// Vtype
struct _jc_ppg_parse_ParserError$vtype {
	_jc_type			type;
	_jc_ppg_parse_ParserError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_parse_ParserError$sub_refs {
	struct _jc_java_lang_String$object	*errorMessage;
};

// Reference instance fields (object)
struct _jc_ppg_parse_ParserError$refs {
    _jc_ppg_parse_ParserError$sub_refs	ppg_parse_ParserError;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_parse_ParserError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_parse_ParserError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_ppg_parse_ParserError$sub_nonrefs	ppg_parse_ParserError;
};

// Object instance structure
struct _jc_ppg_parse_ParserError$object {
	_jc_ppg_parse_ParserError$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_parse_ParserError$vtype	*vtype;
	_jc_ppg_parse_ParserError$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_parse_ParserError$vtype _jc_ppg_parse_ParserError$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_parse_ParserError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_parse_ParserError$class_object;

#endif	/* _JC_ppg_parse_ParserError_H_ */

==> jc-1.4.6.tar.gz: ppg/parse/ParserError.h <==
// public class ppg.parse.ParserError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class f330be4620416da0 ppg_parse_ParserError

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_ppg_parse_ParserError_H_
#define _JC_ppg_parse_ParserError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_ppg_lex_Token$object;

// Typedefs
typedef struct _jc_ppg_parse_ParserError$sub_refs	_jc_ppg_parse_ParserError$sub_refs;
typedef struct _jc_ppg_parse_ParserError$sub_nonrefs	_jc_ppg_parse_ParserError$sub_nonrefs;
typedef struct _jc_ppg_parse_ParserError$refs	_jc_ppg_parse_ParserError$refs;
typedef struct _jc_ppg_parse_ParserError$nonrefs	_jc_ppg_parse_ParserError$nonrefs;
typedef struct _jc_ppg_parse_ParserError$object	_jc_ppg_parse_ParserError$object;

typedef const struct _jc_ppg_parse_ParserError$vmethods	_jc_ppg_parse_ParserError$vmethods;
typedef const struct _jc_ppg_parse_ParserError$vtable	_jc_ppg_parse_ParserError$vtable;
typedef const struct _jc_ppg_parse_ParserError$vtype	_jc_ppg_parse_ParserError$vtype;

// Constructors
extern void _jc_ppg_parse_ParserError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_parse_ParserError$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_parse_ParserError$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_parse_ParserError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_parse_ParserError$method$_init$693b4a8377b96746(_jc_env *, struct _jc_ppg_parse_ParserError$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_ppg_lex_Token$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_parse_ParserError$method$getErrorMessage$88bf10365b208229(_jc_env *, struct _jc_ppg_parse_ParserError$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_parse_ParserError$method_info$getErrorMessage$88bf10365b208229;

// Virtual methods structure
struct _jc_ppg_parse_ParserError$vmethods {
	struct _jc_java_lang_String$object	*(*getErrorMessage$88bf10365b208229)(_jc_env *, struct _jc_ppg_parse_ParserError$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_parse_ParserError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_ppg_parse_ParserError$vmethods	ppg_parse_ParserError;
};

// Vtype
struct _jc_ppg_parse_ParserError$vtype {
	_jc_type			type;
	_jc_ppg_parse_ParserError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_parse_ParserError$sub_refs {
	struct _jc_java_lang_String$object	*errorMessage;
};

// Reference instance fields (object)
struct _jc_ppg_parse_ParserError$refs {
    _jc_ppg_parse_ParserError$sub_refs	ppg_parse_ParserError;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_parse_ParserError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_parse_ParserError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_ppg_parse_ParserError$sub_nonrefs	ppg_parse_ParserError;
};

// Object instance structure
struct _jc_ppg_parse_ParserError$object {
	_jc_ppg_parse_ParserError$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_parse_ParserError$vtype	*vtype;
	_jc_ppg_parse_ParserError$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_parse_ParserError$vtype _jc_ppg_parse_ParserError$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_parse_ParserError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_parse_ParserError$class_object;

#endif	/* _JC_ppg_parse_ParserError_H_ */
